@@ -1,4 +1,4 @@
-/*	$NetBSD: setup.c,v 1.5 1998/09/13 15:23:40 hubertf Exp $	*/
+/*	$NetBSD: setup.c,v 1.6 1999/02/10 00:29:21 hubertf Exp $	*/
 
 /*-
  * Copyright (c) 1991, 1993
@@ -46,7 +46,7 @@ __COPYRIGHT("@(#) Copyright (c) 1991, 1993\n\
 #if 0
 static char sccsid[] = "@(#)setup.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: setup.c,v 1.5 1998/09/13 15:23:40 hubertf Exp $");
+__RCSID("$NetBSD: setup.c,v 1.6 1999/02/10 00:29:21 hubertf Exp $");
 #endif
 #endif				/* not lint */
 
@@ -121,5 +121,8 @@ main(argc, argv)
 	}
 	puts("\n\t0\n};");
 	fclose(infile);
+	fflush(stdout);
+	if (ferror(stdout))
+		err(1, "writing standard output");
 	exit(0);
 }
