@@ -1,4 +1,4 @@
-/*	$NetBSD: subs.c,v 1.8 1998/09/13 15:19:35 hubertf Exp $	*/
+/*	$NetBSD: subs.c,v 1.10 1999/02/10 12:29:48 hubertf Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)subs.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: subs.c,v 1.8 1998/09/13 15:19:35 hubertf Exp $");
+__RCSID("$NetBSD: subs.c,v 1.10 1999/02/10 12:29:48 hubertf Exp $");
 #endif
 #endif /* not lint */
 
@@ -325,7 +325,7 @@ getarg(arg)
 	 * the game is being recovered */
 
 	s = *arg;
-	while (s[0] != NULL && s[0][0] == '-') {
+	while (*s && s[0][0] == '-') {
 		switch (s[0][1]) {
 
 			/* don't ask if rules or instructions needed */
@@ -447,7 +447,7 @@ fixtty(t)
 
 void
 getout(dummy)
-	int     dummy __attribute__((unused));
+	int     dummy __attribute__((__unused__));
 {
 	/* go to bottom of screen */
 	if (tflag) {
