@@ -1,4 +1,4 @@
-/*	$NetBSD: com6.c,v 1.9 1997/10/13 21:05:36 cjs Exp $	*/
+/*	$NetBSD: com6.c,v 1.10 1999/02/10 01:36:50 hubertf Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)com6.c	8.2 (Berkeley) 4/28/95";
 #else
-__RCSID("$NetBSD: com6.c,v 1.9 1997/10/13 21:05:36 cjs Exp $");
+__RCSID("$NetBSD: com6.c,v 1.10 1999/02/10 01:36:50 hubertf Exp $");
 #endif
 #endif				/* not lint */
 
@@ -93,7 +93,7 @@ die()
 
 void
 diesig(dummy)
-	int     dummy __attribute__((unused));
+	int     dummy __attribute__((__unused__));
 {
 	die();
 }
@@ -114,6 +114,8 @@ open_score_file()
 	score_fp = fopen(_PATH_SCORE, "a");
 	if (score_fp == NULL)
 		warn("open %s for append", _PATH_SCORE);
+	if (score_fp != NULL && fileno(score_fp) < 3)
+		exit(1);
 }
 
 void
