@@ -1,4 +1,4 @@
-/*	$NetBSD: globals.c,v 1.6 1997/10/11 02:07:23 lukem Exp $	*/
+/*	$NetBSD: globals.c,v 1.7 1999/02/10 01:36:50 hubertf Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)globals.c	8.2 (Berkeley) 4/28/95";
 #else
-__RCSID("$NetBSD: globals.c,v 1.6 1997/10/11 02:07:23 lukem Exp $");
+__RCSID("$NetBSD: globals.c,v 1.7 1999/02/10 01:36:50 hubertf Exp $");
 #endif
 #endif				/* not lint */
 
@@ -52,7 +52,7 @@ const char   *const objdes[NUMOFOBJECTS] = {
 	"There is an exquisitely crafted sword and scabbard here.",
 	0,			/* can land from here */
 	"There is a fierce woodsman here brandishing a heavy mallet.",
-	"There is an unweildly two-handed sword here.",
+	"There is an unwieldy two-handed sword here.",
 	"There is a bloody meat cleaver here.",
 	"A rusty broadsword is lying here.",
 	"There is an ancient coat of finely woven mail here.",
@@ -96,7 +96,7 @@ const char   *const objdes[NUMOFOBJECTS] = {
 	"There is a colorful pink potion in a small crystal vial here.",
 	"A gold bracelet is on the ground here.",
 	"A swarthy woman with stern features pulls you aside from the crowd,\n'I must talk to you -- but not here.  Meet me at midnight in the gardens.'",
-	"The swarthy woman has been awaiting you anxiousy. 'I must warn you that the\nIsland has anticipated your Quest.  You will not be welcomed. The Darkness is\nstrong where you must search.  Seek not the shadows save only at night, for\nthen are they the weakest.  In the mountains far from here a canyon winds\nwith ferns and streams and forgotten vines.  There you must go. Take this\nrope.'",
+	"The swarthy woman has been awaiting you anxiously. 'I must warn you that the\nIsland has anticipated your Quest.  You will not be welcomed. The Darkness is\nstrong where you must search.  Seek not the shadows save only at night, for\nthen are they the weakest.  In the mountains far from here a canyon winds\nwith ferns and streams and forgotten vines.  There you must go. Take this\nrope.'",
 	"Out from the shadows a figure leaps!  His black cape swirls around, and he\nholds a laser sword at your chest.  'So, you have come to fulfill the Quest.\nHa! Your weapons are no match for me!'",
 	"An old timer with one eye missing and no money for a drink sits at the bar.",
 	"You are flying through an asteroid field!",
