@@ -1689,6 +1689,8 @@ initall()
 
 	if (dbfd < 0)
 		return;
+	if (dbfd < 3)
+		exit(1);
 	i = lseek(dbfd, uid * sizeof(struct betinfo), SEEK_SET);
 	if (i < 0) {
 		close(dbfd);
@@ -1746,7 +1748,7 @@ finish()
  */
 void
 cleanup(dummy)
-	int dummy __attribute__((unused));
+	int dummy __attribute__((__unused__));
 {
 
 	total.thinktime += 1;
@@ -1770,7 +1772,7 @@ cleanup(dummy)
  */
 void
 askquit(dummy)
-	int dummy __attribute__((unused));
+	int dummy __attribute__((__unused__));
 {
 	move(msgrow, msgcol);
 	printw("Really wish to quit?    ");
