@@ -1,4 +1,4 @@
-/*	$NetBSD: fish.c,v 1.5 1997/11/16 21:41:53 christos Exp $	*/
+/*	$NetBSD: fish.c,v 1.6 1998/09/13 15:27:27 hubertf Exp $	*/
 
 /*-
  * Copyright (c) 1990, 1993
@@ -46,7 +46,7 @@ __COPYRIGHT("@(#) Copyright (c) 1990, 1993\n\
 #if 0
 static char sccsid[] = "@(#)fish.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: fish.c,v 1.5 1997/11/16 21:41:53 christos Exp $");
+__RCSID("$NetBSD: fish.c,v 1.6 1998/09/13 15:27:27 hubertf Exp $");
 #endif
 #endif /* not lint */
 
@@ -70,7 +70,7 @@ __RCSID("$NetBSD: fish.c,v 1.5 1997/11/16 21:41:53 christos Exp $");
 #define	COMPUTER	0
 #define	OTHER(a)	(1 - (a))
 
-char *cards[] = {
+const char *const cards[] = {
 	"A", "2", "3", "4", "5", "6", "7",
 	"8", "9", "10", "J", "Q", "K", NULL,
 };
@@ -80,10 +80,10 @@ int promode;
 int asked[RANKS], comphand[RANKS], deck[RANKS];
 int userasked[RANKS], userhand[RANKS];
 
-void	chkwinner __P((int, int *));
+void	chkwinner __P((int, const int *));
 int	compmove __P((void));
-int	countbooks __P((int *));
-int	countcards __P((int *));
+int	countbooks __P((const int *));
+int	countcards __P((const int *));
 int	drawcard __P((int, int *));
 int	gofish __P((int, int, int *));
 void	goodmove __P((int, int, int *, int *));
@@ -91,10 +91,10 @@ void	init __P((void));
 void	instructions __P((void));
 int	main __P((int, char *[]));
 int	nrandom __P((int));
-void	printhand __P((int *));
+void	printhand __P((const int *));
 void	printplayer __P((int));
 int	promove __P((void));
-void	usage __P((void));
+void	usage __P((void)) __attribute__((__noreturn__));
 int	usermove __P((void));
 
 int
@@ -104,6 +104,9 @@ main(argc, argv)
 {
 	int ch, move;
 
+	/* Revoke setgid privileges */
+	setregid(getgid(), getgid());
+
 	while ((ch = getopt(argc, argv, "p")) != -1)
 		switch(ch) {
 		case 'p':
@@ -111,8 +114,7 @@ main(argc, argv)
 			break;
 		case '?':
 		default:
-			(void)fprintf(stderr, "usage: fish [-p]\n");
-			exit(1);
+			usage();
 		}
 
 	srandom(time((time_t *)NULL));
@@ -153,7 +155,7 @@ int
 usermove()
 {
 	int n;
-	char **p;
+	const char *const *p;
 	char buf[256];
 
 	(void)printf("\nYour hand is:");
@@ -328,7 +330,7 @@ goodmove(player, move, hand, opphand)
 void
 chkwinner(player, hand)
 	int player;
-	int *hand;
+	const int *hand;
 {
 	int cb, i, ub;
 
@@ -371,7 +373,7 @@ printplayer(player)
 
 void
 printhand(hand)
-	int *hand;
+	const int *hand;
 {
 	int book, i, j;
 
@@ -392,7 +394,7 @@ printhand(hand)
 
 int
 countcards(hand)
-	int *hand;
+	const int *hand;
 {
 	int i, count;
 
@@ -403,7 +405,7 @@ countcards(hand)
 
 int
 countbooks(hand)
-	int *hand;
+	const int *hand;
 {
 	int i, count;
 
@@ -450,6 +452,8 @@ instructions()
 {
 	int input;
 	pid_t pid;
+	int fd;
+	const char *pager;
 	int status;
 
 	(void)printf("Would you like instructions (y or n)? ");
@@ -460,10 +464,18 @@ instructions()
 
 	switch (pid = fork()) {
 	case 0: /* child */
-		(void)setuid(getuid());
-		(void)setgid(getgid());
-		(void)execl(_PATH_MORE, "more", _PATH_INSTR, NULL);
-		err(1, "%s %s", _PATH_MORE, _PATH_INSTR);
+		if (!isatty(1))
+			pager = "cat";
+		else {
+			if (!(pager = getenv("PAGER")) || (*pager == 0))
+				pager = _PATH_MORE;
+		}
+		if ((fd = open(_PATH_INSTR, O_RDONLY)) == -1)
+			err(1, "open %s", _PATH_INSTR);
+		if (dup2(fd, 0) == -1)
+			err(1, "dup2");
+		(void)execl("/bin/sh", "sh", "-c", pager, NULL);
+		err(1, "exec sh -c %s", pager);
 		/*NOTREACHED*/
 	case -1:
 		err(1, "fork");
