@@ -95,11 +95,6 @@ __RCSID("$NetBSD: strfile.c,v 1.8 1998/09/13 15:27:28 hubertf Exp $");
 # define	STORING_PTRS	(Oflag || Rflag)
 # define	CHUNKSIZE	512
 
-#ifdef lint
-# define	ALWAYS	atoi("1")
-#else
-# define	ALWAYS	1
-#endif
 # define	ALLOC(ptr,sz)	do { \
 			if (ptr == NULL) \
 				ptr = malloc((unsigned int) (CHUNKSIZE * sizeof *ptr)); \
@@ -177,7 +172,7 @@ main(ac, av)
 	if ((outf = fopen(Outfile, "w")) == NULL)
 		err(1, "open `%s'", Outfile);
 	if (!STORING_PTRS)
-		(void) fseek(outf, sizeof Tbl, 0);
+		(void) fseek(outf, sizeof Tbl, SEEK_SET);
 
 	/*
 	 * Write the strings onto the file
@@ -245,7 +240,7 @@ main(ac, av)
 		       Tbl.str_shortlen == 1 ? "" : "s");
 	}
 
-	(void) fseek(outf, (off_t) 0, 0);
+	(void) fseek(outf, (off_t) 0, SEEK_SET);
 	Tbl.str_version = htonl(Tbl.str_version);
 	Tbl.str_numstr = htonl(Num_pts - 1);
 	Tbl.str_longlen = htonl(Tbl.str_longlen);
@@ -257,6 +252,9 @@ main(ac, av)
 			*p = htonl(*p);
 		(void) fwrite((char *) Seekpts, sizeof *Seekpts, (int) Num_pts, outf);
 	}
+	fflush(outf);
+	if (ferror(outf))
+		err(1, "fwrite %s", Outfile);
 	(void) fclose(outf);
 	exit(0);
 }
@@ -413,8 +411,8 @@ cmp_str(vp1, vp2)
 	if (c1 != c2)
 		return c1 - c2;
 
-	(void) fseek(Sort_1, p1->pos, 0);
-	(void) fseek(Sort_2, p2->pos, 0);
+	(void) fseek(Sort_1, p1->pos, SEEK_SET);
+	(void) fseek(Sort_2, p2->pos, SEEK_SET);
 
 	n1 = FALSE;
 	n2 = FALSE;
