@@ -74,7 +74,7 @@ main(void)
  */
 void
 die(dummy)
-	int dummy __attribute__((unused));
+	int dummy __attribute__((__unused__));
 {
 	mvcur(0, COLS - 1, LINES - 1, 0);
 	endwin();
