@@ -10,23 +10,27 @@ fgetln(FILE *stream, size_t *len)
   static size_t buflen = 0;
   char *res;
   char *nbuf;
-  if (buf == NULL)
+  if (buf == NULL) {
     buf = (char *)malloc(buflen = 1024);
+    if (buf == NULL) {
+      return NULL;
+    }
+  }
   buf[buflen - 1] = 1;
   res = fgets(buf, buflen, stream);
   if (res == NULL)
-    return(NULL);
+    return NULL;
   while (buf[buflen - 1] == 0) { /* long line */
     nbuf = realloc(buf, buflen * 2);
     if (nbuf == NULL)
-      return(NULL);
+      return NULL;
     buf = nbuf;
     buflen *= 2;
     buf[buflen - 1] = 1;
     res = fgets(buf + buflen/2 - 1, buflen/2 + 1, stream);
     if (res == NULL)
-      return(NULL);
+      return NULL;
   }
   *len = strlen(buf);
-  return(buf);
+  return buf;
 }
