@@ -35,6 +35,7 @@
  *	@(#)monop.h	8.1 (Berkeley) 5/31/93
  */
 
+# include	<err.h>
 # include	<stdio.h>
 # include	<stdlib.h>
 # include	<string.h>
@@ -76,7 +77,7 @@
 				}
 
 struct sqr_st {			/* structure for square			*/
-	char	*name;			/* place name			*/
+	const char	*name;		/* place name			*/
 	short	owner;			/* owner number			*/
 	short	type;			/* place type			*/
 	struct prp_st	*desc;		/* description struct		*/
@@ -86,13 +87,13 @@ struct sqr_st {			/* structure for square			*/
 typedef struct sqr_st	SQUARE;
 
 struct mon_st {			/* monopoly description structure	*/
-	char	*name;			/* monop. name (color)		*/
+	const char	*name;		/* monop. name (color)		*/
 	short	owner;			/* owner of monopoly		*/
 	short	num_in;			/* # in monopoly		*/
 	short	num_own;		/* # owned (-1: not poss. monop)*/
 	short	h_cost;			/* price of houses		*/
-	char	*not_m;			/* name if not monopoly		*/
-	char	*mon_n;			/* name if a monopoly		*/
+	const char	*not_m;		/* name if not monopoly		*/
+	const char	*mon_n;		/* name if a monopoly		*/
 	unsigned char	sqnums[3];	/* Square numbers (used to init)*/
 	SQUARE	*sq[3];			/* list of squares in monop	*/
 };
@@ -146,10 +147,10 @@ void do_move __P((void));
 void move __P((int));
 void save __P((void));
 void restore __P((void));
-int rest_f __P((char *));
+int rest_f __P((const char *));
 
 /* getinp.c */
-int getinp __P((char *, char *[]));
+int getinp __P((const char *, const char *const []));
 
 /* houses.c */
 void buy_houses __P((void));
@@ -163,10 +164,10 @@ int move_jail __P((int, int ));
 void printturn __P((void));
 
 /* misc.c */
-int getyn __P((char *));
+int getyn __P((const char *));
 void notify __P((void));
 void next_play __P((void));
-int get_int __P((char *));
+int get_int __P((const char *));
 void set_ownlist __P((int));
 void is_monop __P((MON *, int));
 void is_not_monop __P((MON *));
