@@ -153,7 +153,7 @@ interrupt()
 
 int
 getanswer(choices, def)
-	char   *choices;
+	const char   *choices;
 	bool    def;
 {
 	int     ch;		/* input */
@@ -238,7 +238,7 @@ getanswer(choices, def)
 
 void
 catchalarm(dummy)
-	int dummy __attribute__((unused));
+	int dummy __attribute__((__unused__));
 {
 	longjmp(Timeoenv, 1);
 }
