@@ -288,6 +288,8 @@ initialstate()
 	if ((Playersfp = fopen(_PATH_PEOPLE, "r+")) == NULL)
 		error(_PATH_PEOPLE);
 	/* NOTREACHED */
+	if (fileno(Playersfp) < 3)
+		exit(1);
 
 	if ((Monstfp = fopen(_PATH_MONST, "r+")) == NULL)
 		error(_PATH_MONST);
@@ -627,7 +629,7 @@ titlelist()
 		fclose(fp);
 	}
 	/* search for king */
-	fseek(Playersfp, 0L, 0);
+	fseek(Playersfp, 0L, SEEK_SET);
 	while (fread((char *) &Other, SZ_PLAYERSTRUCT, 1, Playersfp) == 1)
 		if (Other.p_specialtype == SC_KING &&
 		    Other.p_status != S_NOTUSED)
@@ -643,7 +645,7 @@ titlelist()
 		mvaddstr(4, 24, "There is no ruler at this time.");
 
 	/* search for valar */
-	fseek(Playersfp, 0L, 0);
+	fseek(Playersfp, 0L, SEEK_SET);
 	while (fread((char *) &Other, SZ_PLAYERSTRUCT, 1, Playersfp) == 1)
 		if (Other.p_specialtype == SC_VALAR && Other.p_status != S_NOTUSED)
 			/* found the valar */
@@ -653,7 +655,7 @@ titlelist()
 			break;
 		}
 	/* search for council of the wise */
-	fseek(Playersfp, 0L, 0);
+	fseek(Playersfp, 0L, SEEK_SET);
 	Lines = 10;
 	while (fread((char *) &Other, SZ_PLAYERSTRUCT, 1, Playersfp) == 1)
 		if (Other.p_specialtype == SC_COUNCIL && Other.p_status != S_NOTUSED)
@@ -672,7 +674,7 @@ titlelist()
 	hiexp = 0.0;
 	nxtlvl = hilvl = 0;
 
-	fseek(Playersfp, 0L, 0);
+	fseek(Playersfp, 0L, SEEK_SET);
 	while (fread((char *) &Other, SZ_PLAYERSTRUCT, 1, Playersfp) == 1)
 		if (Other.p_experience > hiexp && Other.p_specialtype <= SC_KING && Other.p_status != S_NOTUSED)
 			/* highest found so far */
@@ -874,7 +876,7 @@ genchar(type)
 	int     type;
 {
 	int     subscript;	/* used for subscripting into Stattable */
-	struct charstats *statptr;	/* for pointing into Stattable */
+	const struct charstats *statptr; /* for pointing into Stattable */
 
 	subscript = type - '1';
 
