@@ -195,7 +195,7 @@ move(sp)
 
 void
 gto(sp)
-	struct point *sp;
+	const struct point *sp;
 {
 
 	int     distance, f, tfield;
@@ -267,7 +267,7 @@ gto(sp)
 
 void
 right(sp)
-	struct point *sp;
+	const struct point *sp;
 {
 	int     field, tfield;
 	int     tabcol, strlength;
@@ -432,10 +432,10 @@ pch(c)
 
 void
 #if __STDC__
-apr(struct point * ps, const char *fmt,...)
+apr(const struct point * ps, const char *fmt,...)
 #else
 apr(ps, fmt, va_alist)
-	struct point *ps;
+	const struct point *ps;
 	char   *fmt;
 va_dcl
 #endif
@@ -515,7 +515,7 @@ pstring(s)
 
 void
 pchar(ps, ch)
-	struct point *ps;
+	const struct point *ps;
 	char    ch;
 {
 	struct point p;
@@ -549,7 +549,7 @@ outch(c)
 
 void
 putpad(str)
-	char *str;
+	const char *str;
 {
 	if (str)
 		tputs(str, 1, outch);
