@@ -1,4 +1,4 @@
-/*	$NetBSD: tetris.h,v 1.3 1998/09/13 15:27:30 hubertf Exp $	*/
+/*	$NetBSD: tetris.h,v 1.5 1999/01/03 17:13:51 hubertf Exp $	*/
 
 /*-
  * Copyright (c) 1992, 1993
@@ -131,9 +131,12 @@ struct shape {
 	int	off[3];	/* offsets to other blots if center is at (0,0) */
 };
 
-extern struct shape shapes[];
+extern const struct shape shapes[];
 #define	randshape() (&shapes[random() % 7])
 
+const struct shape *curshape;
+const struct shape *nextshape;
+
 /*
  * Shapes fall at a rate faster than once per second.
  *
@@ -168,7 +171,8 @@ int	score;			/* the obvious thing */
 gid_t	gid, egid;
 
 char	key_msg[100];
+int	showpreview;
 
-int	fits_in __P((struct shape *, int));
-void	place __P((struct shape *, int, int));
-void	stop __P((char *)) __attribute__((__noreturn__));
+int	fits_in __P((const struct shape *, int));
+void	place __P((const struct shape *, int, int));
+void	stop __P((const char *)) __attribute__((__noreturn__));
